ImmuneDB
========

[![Build Status](https://img.shields.io/travis/arosenfeld/immunedb/master.svg)](https://travis-ci.org/arosenfeld/immunedb)
[![codecov](https://codecov.io/gh/arosenfeld/immunedb/branch/master/graph/badge.svg)](https://codecov.io/gh/arosenfeld/immunedb)
[![PyPI](https://img.shields.io/pypi/v/immunedb.svg)](https://pypi.python.org/pypi/ImmuneDB)
[![Docker Pulls](https://img.shields.io/docker/pulls/arosenfeld/immunedb.svg)](https://hub.docker.com/r/arosenfeld/immunedb)

ImmuneDB is a Python module that facilitates efficient storage and analysis of
high-throughput B- and T-cell sequence data.

# Documentation
Installation and usage instructions can be found at [immunedb.com](http://immunedb.com)

# Citing
If you use ImmuneDB, please cite the tool as:

Aaron M. Rosenfeld, Wenzhao Meng, Eline T. Luning Prak, and Uri Hershberg,
**ImmuneDB: a system for the analysis and exploration of high-throughput
adaptive immune receptor sequencing data**, Bioinformatics **33** (2016), no. 2,
292–293.
